% STK_IMPROVEMENT_PROB_EVAL(zp_mean, zp_std, zi, zr)
% compute probability for a point not to be dominated
%
% CALL: [ PI ] = STK_IMPROVEMENT_PROB_EVAL(ZP_MEAN, ZP_STD, ZI, ZR)
% compute probability for some points not to be dominated by some points ZI
% based on the mean and squared-deviation ZP_MEAN and ZP_STD (from model).
% ZR is a reference.
%
% See also stk_sampcrit_ehvi_eval, stk_optim_ehvi_smc

% Copyright Notice
%
%    Copyright (C) 2017 CentraleSupelec
%
%    Authors:  Etienne Leloup          <etienne.leloup@free.fr>
%              Guillaume Maistre-Bazin <g.maistre.bazin@gmail.com>
%              Lucain Pouget           <lucainp@gmail.com>

% Copying Permission Statement
%
%    This file is part of STK-contrib-moo-1
%      (https://sourceforge.net/p/kriging/contrib-moo-1/).
%
%    STK-contrib-moo-1 is free software;  you can redistribute it  and/or
%    modify it  under the terms of the  GNU Lesser General Public License
%    as published by the Free Software Foundation;  either version 2.1 of
%    the License, or (at your option) any later version.
%
%    STK-contrib-moo-1 is distributed in the hope that it will be useful,
%    but  WITHOUT  ANY  WARRANTY;  without even  the implied  warranty of
%    MERCHANTABILITY or FITNESS  FOR A  PARTICULAR PURPOSE.  See the  GNU
%    Lesser General Public License for more details.
%
%    You should  have received  a copy  of the  GNU Lesser General Public
%    License along with STK-contrib-moo-1;  if not, see
%                                          <http://www.gnu.org/licenses/>.


function [ Pi ] = stk_improvement_prob_eval (zp_mean, zp_std, zi, zr)

% Compute probability for a point not to be dominated
Pr = stk_distrib_normal_cdf (zr, zp_mean, zp_std);
Pi = prod (Pr, 2);

S = stk_dominatedhv (zi, zr, 1);

if ~ isempty (S.sign)
    
    Rs = shiftdim (S.sign,  -2);
    Ra = shiftdim (S.xmin', -1);
    Rb = shiftdim (S.xmax', -1);
    
    Pia = stk_distrib_normal_cdf (Ra, zp_mean, zp_std);  % m x p x R
    Pib = stk_distrib_normal_cdf (Rb, zp_mean, zp_std);  % m x p x R
    
    Pi = Pi - sum (bsxfun (@times, Rs, prod (Pib - Pia, 2)), 3);
    
end

end % function
