% STK_OPTIM_EHVI_GRID optimizes the EHVI criteria on a given scatter plot
%
% CALL: [x_opt, ehvi_opt] = stk_optim_ehvi_grid (XG, MODEL, DATA, Z_REF)
%
%    optimizes the EHVI criteria on the grid XG, given the DATA and MODEL with
%    respect to a reference Z_REF.
%
% See also stk_optim_ehvi

% Copyright Notice
%
%    Copyright (C) 2017 CentraleSupelec
%
%    Authors:  Etienne Leloup           <etienne.leloup@free.fr>
%              Guillaume Maistre-Bazin  <g.maistre.bazin@gmail.com>
%              Lucain Pouget            <lucainp@gmail.com>
%              Julien Bect              <julien.bect@centralesupelec.fr>

% Copying Permission Statement
%
%    This file is part of STK-contrib-moo-1
%      (https://sourceforge.net/p/kriging/contrib-moo-1/).
%
%    STK-contrib-moo-1 is free software;  you can redistribute it  and/or
%    modify it  under the terms of the  GNU Lesser General Public License
%    as published by the Free Software Foundation;  either version 2.1 of
%    the License, or (at your option) any later version.
%
%    STK-contrib-moo-1 is distributed in the hope that it will be useful,
%    but  WITHOUT  ANY  WARRANTY;  without even  the implied  warranty of
%    MERCHANTABILITY or FITNESS  FOR A  PARTICULAR PURPOSE.  See the  GNU
%    Lesser General Public License for more details.
%
%    You should  have received  a copy  of the  GNU Lesser General Public
%    License along with STK-contrib-moo-1;  if not, see
%                                          <http://www.gnu.org/licenses/>.

function [x_opt, ehvi_opt] = stk_optim_ehvi_grid (xg, model, data, z_ref)

% Compute EHVI on grid
ehvi_val = compute_ehvi (data, xg, model, z_ref);

% Get max and return value
[ehvi_opt, i_max] = max (ehvi_val);
x_opt = xg(i_max, :);

end % function
