% STK_OPTIM_EHVI_SRS optimizes the EHVI criteria using simple random search
%
% CALL: [x_opt, ehvi_opt, AUX] = stk_optim_ehvi_srs ...
%          (OPTIONS, DOM, MODEL, DATA, Z_REF)
%
%    optimizes the EHVI criterion with Simple Random Search (SRS).
%    Optimization done given a MODEL and some DATA in the domain DOM, with
%    respect to a reference Z_REF. METHOD can be 'SMC', 'GA' (for
%    the genetic algorithm of Matlab) or 'SRS' to optimize on a randunif grid.
%    Parameters X and SIGMA can be given for the SMC algorithm.
%    Some points of DATA may not be evaluated yet. A realisation is simulated
%    instead, given the MODEL.
%
% See also stk_optim_ehvi_grid, stk_optim_ehvi_smc, stk_example_boo01,
%          stk_example_boo02, stk_example_boo03

% Copyright Notice
%
%    Copyright (C) 2017 CentraleSupelec
%
%    Authors:  Etienne Leloup           <etienne.leloup@free.fr>
%              Guillaume Maistre-Bazin  <g.maistre.bazin@gmail.com>
%              Lucain Pouget            <lucainp@gmail.com>
%              Julien Bect              <julien.bect@centralesupelec.fr>

% Copying Permission Statement
%
%    This file is part of STK-contrib-moo-1
%      (https://sourceforge.net/p/kriging/contrib-moo-1/).
%
%    STK-contrib-moo-1 is free software;  you can redistribute it  and/or
%    modify it  under the terms of the  GNU Lesser General Public License
%    as published by the Free Software Foundation;  either version 2.1 of
%    the License, or (at your option) any later version.
%
%    STK-contrib-moo-1 is distributed in the hope that it will be useful,
%    but  WITHOUT  ANY  WARRANTY;  without even  the implied  warranty of
%    MERCHANTABILITY or FITNESS  FOR A  PARTICULAR PURPOSE.  See the  GNU
%    Lesser General Public License for more details.
%
%    You should  have received  a copy  of the  GNU Lesser General Public
%    License along with STK-contrib-moo-1;  if not, see
%                                          <http://www.gnu.org/licenses/>.

function [x_opt, ehvi_opt, aux] = stk_optim_ehvi_srs ...
    (options, box, model, data, z_ref)

% Default sample size
if ~ isfield (options, 'population_size') || isempty (options.population_size)
    options.population_size = 1000;
end

% Check that batch_size is 1
if isfield (options, 'batch_size') && (options.batch_size > 1)
    stk_error ('options.batch_size > 1 not supported in this function')
end

xg = stk_sampling_randunif (options.population_size, [], box);

[x_opt, ehvi_opt] = stk_optim_ehvi_grid (xg, model, data, z_ref);

aux = [];

end % function
