% STK_SMC_RESAMPLE applies a residual resampling step to an SMC sample
%
% CALL: SMC = stk_smc_resample (SMC)
%
%    resamples the SMC sample using the residual resampling scheme.
%
% See also stk_optim_ehvi_smc, stk_smc_initialize,
%          stk_smc_reweight, stk_smc_move

% Copyright Notice
%
%    Copyright (C) 2017 CentraleSupelec
%
%    Authors:  Julien Bect  <julien.bect@centralesupelec.fr>

% Copying Permission Statement
%
%    This file is part of STK-contrib-moo-1
%      (https://sourceforge.net/p/kriging/contrib-moo-1/).
%
%    STK-contrib-moo-1 is free software;  you can redistribute it  and/or
%    modify it  under the terms of the  GNU Lesser General Public License
%    as published by the Free Software Foundation;  either version 2.1 of
%    the License, or (at your option) any later version.
%
%    STK-contrib-moo-1 is distributed in the hope that it will be useful,
%    but  WITHOUT  ANY  WARRANTY;  without even  the implied  warranty of
%    MERCHANTABILITY or FITNESS  FOR A  PARTICULAR PURPOSE.  See the  GNU
%    Lesser General Public License for more details.
%
%    You should  have received  a copy  of the  GNU Lesser General Public
%    License along with STK-contrib-moo-1;  if not, see
%                                          <http://www.gnu.org/licenses/>.

function smc = stk_smc_resample (smc)

[pop_size, dim] = size (smc.particles);

% Draw the number of copies of each particles
nb_copies = residual_resampling (smc.weights);
idx_copied = find (nb_copies > 0);

% Prepare the new sample
s.particles = zeros (pop_size, dim);
s.weights   = repmat (1/pop_size, pop_size, 1);
s.updf_fun  = smc.updf_fun;
s.updf_val  = zeros (pop_size, 1);

% Copy particles with multiplicity
k_deb = 1;
for i = idx_copied'
    k_fin = k_deb + nb_copies(i) - 1;
    s.particles(k_deb:k_fin, :) = repmat (smc.particles(i, :), nb_copies(i), 1);
    s.updf_val(k_deb:k_fin) = smc.updf_val(i);
    k_deb = k_fin + 1;
end

smc = s;

%*** TEMP: DEBUG ***%
if any (isnan (smc.updf_val)) || any (isnan (smc.weights))
    error ('There are NaNs in smc.updf_val or smc.weights');
end
if ~ all ((smc.updf_val > 0) & (smc.weights > 0))
    error ('Particles should have a non-negative weight at this point');
end

end % function
